# Security Policy

## Supported Versions

The AsyncAPI Payload Validator operates on a rolling release model, with the latest release being the only supported version.

## Reporting a Vulnerability

The repository is actively monitored for security issues through GitHub's security features.
However, in case you identify a potential vulnerability, please use the [security advisory form](https://github.com/ingka-group/asyncapi-payload-validator/security/advisories/new).